@@ -1,7 +1,7 @@
 import numpy as np
 import numba as nb
 
-@nb.jit(nopython=True,parallel=True,fastmath=True,nogil=True,cache=True,boundscheck=False)
+@nb.jit(nopython=True,fastmath=True)
 def fitness(x,H_0,dim=3):
     n = H_0.shape[0]//dim
     a = np.ones(n*dim)
