@@ -1,11 +1,21 @@
 import os
+from .setup import setup as setup_file
+from .paths import paths as path_file
+from .contour import contour as contour_file
+from .geometry import geometry as geometry_file
+from .loft import loft as loft_file
+from .solid import solid as solid_file
+from .mesh import mesh as mesh_file
+from .presolver import presolver as presolver_file
+from .solver import solver as solver_file
+from .centerline import centerline as centerline_file
 
 def build(paths,radii,normals,options):
     cco_filename = options.filename
     if options.directory_constructor['create_main_folder']:
         os.mkdir(options.directory_constructor['main_folder'])
     cco_file = open(cco_filename,'w+')
-    setup_file = open(os.path.dirname(__file__)+'/setup.txt','r').read()
+    #setup_file = open(os.path.dirname(__file__)+'/setup.txt','r').read()
     if options.file_constructor['path']:
         path_file = open(os.path.dirname(__file__)+'/paths.txt','r').read()
         path_file = path_file.format(options.file_constructor['gui'])
