@@ -108,6 +108,9 @@ class tree:
             self.sub_division_map = sub_division_map
             self.sub_division_index = sub_division_index
 
+    def n_add(self,n):
+        for i in tqdm(range(n),desc='Adding vessels'):
+            self.add(-1,0)
 
     def show(self,surface=False,vessel_colors='red',background_color='white',
              resolution=100,show_segments=True):
